<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xs="http://www.w3.org/2001/XMLSchema" 
  xmlns:regexp="http://exslt.org/regular-expressions"
	xmlns="urn:oasis:names:specification:ubl:schema:xsd:Invoice-2"
	xmlns:ds="http://www.w3.org/2000/09/xmldsig#"
	xmlns:ext="urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2"
	xmlns:sac="urn:sunat:names:specification:ubl:peru:schema:xsd:SunatAggregateComponents-1"
	xmlns:cbc="urn:oasis:names:specification:ubl:schema:xsd:CommonBasicComponents-2"
	xmlns:cac="urn:oasis:names:specification:ubl:schema:xsd:CommonAggregateComponents-2"
	xmlns:date="http://exslt.org/dates-and-times" version="2.0">
	<!-- key Documentos Relacionados Duplicados -->
	<xsl:key name="by-document-billing-reference" match="cac:BillingReference"
		use="concat(cac:InvoiceDocumentReference/cbc:DocumentTypeCode,' ', cac:InvoiceDocumentReference/cbc:ID)" />
	<xsl:key name="by-document-despatch-reference" match="cac:DespatchDocumentReference"
		use="concat(cbc:DocumentTypeCode,' ', cbc:ID)" />
	<xsl:key name="by-document-additional-reference" match="cac:AdditionalDocumentReference"
		use="concat(cbc:DocumentTypeCode,' ', cbc:ID)" />
	<!-- key Documentos Relacionados Duplicados fin -->

	<xsl:key name="by-pricingReference-alternativeConditionPrice-priceTypeCode"
		match="./cac:PricingReference/cac:AlternativeConditionPrice" use="cbc:PriceTypeCode" />

	<xsl:template match="/*">
		<xsl:variable name="sacAdditionalInformation"
			select="ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/sac:AdditionalInformation" />

		<xsl:if test="count($sacAdditionalInformation)>1">
			<xsl:message terminate="yes" >
				<xsl:value-of select="'Error Expr Regular ND  (codigo: 2427)'" />
			</xsl:message>
		</xsl:if>
		<!-- Numero del Documento del emisor - Nro RUC -->
		<xsl:choose>
			<xsl:when
				test="not(string(cac:AccountingSupplierParty/cbc:CustomerAssignedAccountID))">
				<xsl:message terminate="yes" >
					<xsl:value-of select="'Error Expr Regular ND (codigo: 1006)'" />
				</xsl:message>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if
					test='not(matches(cac:AccountingSupplierParty/cbc:CustomerAssignedAccountID,"^[0-9]{11}$"))'>
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 1005)'" />
					</xsl:message>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>

		<!-- Tipo de documento de identidad del emisor - siempre debe de ser RUC -->
		<xsl:if
			test="not(string(cac:AccountingSupplierParty/cbc:AdditionalAccountID))">
			<xsl:message terminate="yes" >
				<xsl:value-of select="'Error Expr Regular ND (codigo: 1008)'" />
			</xsl:message>
		</xsl:if>
		<xsl:if
			test='not(matches(cac:AccountingSupplierParty/cbc:AdditionalAccountID,"^[6]{1}$"))'>
			<xsl:message terminate="yes" >
				<xsl:value-of select="'Error Expr Regular ND (codigo: 1007)'" />
			</xsl:message>
		</xsl:if>
		<xsl:if test="count(cac:AccountingSupplierParty/cbc:AdditionalAccountID)>1">
			<xsl:message terminate="yes" >
				<xsl:value-of select="'Error Expr Regular ND (codigo: 2362)'" />
			</xsl:message>
		</xsl:if>

		<!-- Numeracion, conformada por serie y numero correlativo -->
		<xsl:choose>
			<xsl:when test="not(string(cbc:ID))">
				<xsl:message terminate="yes" >
					<xsl:value-of select="'Error Expr Regular ND (codigo: 1002)'" />
				</xsl:message>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test='not(matches(cbc:ID,"^[F|B][A-Z0-9]{3}-[0-9]{1,8}"))'>
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 1001)'" />
					</xsl:message>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>

		<!-- Version de la Estructura del Documento -->
		<xsl:choose>
			<xsl:when test="not(string(cbc:CustomizationID))">
				<xsl:message terminate="yes" >
					<xsl:value-of select="'Error Expr Regular ND (codigo: 2073)'" />
				</xsl:message>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if
					test='not(matches(cbc:CustomizationID,"^[0-9]{1,7}(\.[0-9]{1,2})?$"))'>
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2072)'" />
					</xsl:message>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>

		<!-- Version del UBL -->
		<xsl:choose>
			<xsl:when test="not(string(cbc:UBLVersionID))">
				<xsl:message terminate="yes" >
					<xsl:value-of select="'Error Expr Regular ND (codigo: 2075)'" />
				</xsl:message>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test='not(matches(cbc:UBLVersionID,"^[2]{1}(\.[0]{1})$"))'>
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2074)'" />
					</xsl:message>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>

		<!-- Fecha de emision -->
		<xsl:choose>
			<xsl:when test="(not(cbc:IssueDate))">
				<xsl:message terminate="yes" >
					<xsl:value-of select="'Error Expr Regular ND (codigo: 1010)'" />
				</xsl:message>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if
					test='not(matches(cbc:IssueDate,"^[0-9]{4}-[0-9]{2}-[0-9]{2}$"))'>
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 1009)'" />
					</xsl:message>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>

		<xsl:variable name="issuedate1" select="//cbc:IssueDate" />
    <!-- INICIO DCERRENO -->
    <!--<xsl:variable name="currentdate" select="current-date()"></xsl:variable>-->
		<!-- <xsl:if	test="((substring-before(difference($currentdate, concat($issuedate1,'-00:00')),'D') != 'P0') and (substring-before(difference($currentdate, concat($issuedate1,'-00:00')),'P')  != substring-before('-P','P')))"> 
			<xsl:message terminate="yes" >
				<xsl:value-of select="'Error Expr Regular ND (codigo: 1011)'" />
			</xsl:message>
		</xsl:if>-->
        <!-- FIN DCERRENO -->

		<!-- Apellidos y nombres o denominacion o razon social Emisor -->
		<!-- modificado 27/01/2014 fin -->
		<xsl:choose>
			<xsl:when
				test="not(string(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cbc:RegistrationName))">
				<xsl:message terminate="yes" >
					<xsl:value-of select="'Error Expr Regular ND (codigo: 1037)'" />
				</xsl:message>
			</xsl:when>
			<xsl:otherwise>
        <!-- INICIO DCERRENO -->
				<!--<xsl:if	test='not(matches(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cbc:RegistrationName,"^(?!\s*$).{1,100}"))'>-->
        <xsl:if	test='not(matches(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cbc:RegistrationName,"^{1,100}"))'>
        <!-- FIN DCERRENO -->
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 1038)'" />
					</xsl:message>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
		<!-- modificado 27/01/2014 fin -->



		<!-- Valida que el numerode documento del adquirente existe y si es RUC 
			valida que conste de 11 caracteres numericos -->
		<xsl:choose>
			<xsl:when
				test="not(string(cac:AccountingCustomerParty/cbc:CustomerAssignedAccountID))">
				<xsl:message terminate="yes" >
					<xsl:value-of select="'Error Expr Regular ND (codigo: 2014)'" />
				</xsl:message>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if
					test="cac:AccountingCustomerParty/cbc:AdditionalAccountID[text()='6'] and not(matches(cac:AccountingCustomerParty/cbc:CustomerAssignedAccountID,'^[0-9]{11}$|^[-]{1}$'))">
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2017)'" />
					</xsl:message>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>

		<!-- Valida que el tipo de documento del adquiriente exista y sea solo 
			uno -->
		<xsl:if test="count(cac:AccountingCustomerParty/cbc:AdditionalAccountID)>1">
			<xsl:message terminate="yes" >
				<xsl:value-of select="'Error Expr Regular ND (codigo: 2363)'" />
			</xsl:message>
		</xsl:if>

		<!-- Valida que el tipo de documento del adquiriente exista -->
		<xsl:if
			test="not(string(cac:AccountingCustomerParty/cbc:AdditionalAccountID))">
			<xsl:message terminate="yes" >
				<xsl:value-of select="'Error Expr Regular ND (codigo: 2015)'" />
			</xsl:message>
		</xsl:if>

		<!-- Si la operacion no es de exportacion el tipo de documento tiene que 
			ser 6, caso contrario puede ser 01467A o guion -->

		<xsl:choose>
			<xsl:when
				test="cac:DebitNoteLine/cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cbc:TaxExemptionReasonCode[text()='40']">
				<xsl:if
					test='not(matches(cac:AccountingCustomerParty/cbc:AdditionalAccountID,"^[01467A\-]{1}$"))'>
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2016)'" />
					</xsl:message>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if
					test='not(cac:AccountingCustomerParty/cbc:AdditionalAccountID[text()=6 or text()=1])'>
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2016)'" />
					</xsl:message>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>


		<!-- Apellidos y nombres o denominacion o razon social del adquirente o 
			usuario -->
		<xsl:choose>
			<xsl:when
				test="not(string(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cbc:RegistrationName))">
				<xsl:message terminate="yes" >
					<xsl:value-of select="'Error Expr Regular ND (codigo: 2021)'" />
				</xsl:message>
			</xsl:when>
			<xsl:otherwise>
      <!-- INICIO DCERRENO -->
				<!--<xsl:if	test='not(matches(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cbc:RegistrationName,"^(?!\s*$).{1,100}"))'>-->
        <xsl:if	test='not(matches(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cbc:RegistrationName,"^{1,100}"))'>
      <!-- FIN DCERRENO -->  
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2022)'" />
					</xsl:message>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>


		<!-- Detalle Nota de Debito -->
		<xsl:for-each select="cac:DebitNoteLine">

			<!-- Valor de venta por item -->
			<xsl:choose>
				<xsl:when test="not(./cbc:LineExtensionAmount)">
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2191)'" />
					</xsl:message>
				</xsl:when>
				<xsl:otherwise>
					<xsl:if
						test='not(matches(./cbc:LineExtensionAmount,"(-?[0-9]+){1,12}(\.[0-9]{1,2})?$"))'>
						<xsl:message terminate="yes" >
							<xsl:value-of select="'Error Expr Regular ND (codigo: 2370)'" />
						</xsl:message>
					</xsl:if>
				</xsl:otherwise>
			</xsl:choose>

			<!-- Numero de orden del item -->
			<xsl:if test='not(matches(./cbc:ID,"^[0-9]{1,3}?$"))'>
				<xsl:message terminate="yes" >
					<xsl:value-of select="'Error Expr Regular ND (codigo: 2187)'" />
				</xsl:message>
			</xsl:if>

			<!-- Unidad de medida por item que modifica -->
			<xsl:if test='./cbc:DebitedQuantity/@unitCode'>
				<xsl:if
					test='not(matches(./cbc:DebitedQuantity/@unitCode,"^[A-Z0-9]{1,3}?$"))'>
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2188)'" />
					</xsl:message>
				</xsl:if>
			</xsl:if>

			<!-- Cantidad de unidades por item -->
			<xsl:if test='./cbc:DebitedQuantity'>
				<xsl:if
					test='not(matches(./cbc:DebitedQuantity,"^[0-9]{1,12}(\.[0-9]{1,10})?$"))'><!--16/01/2015 se corrigio la cantidad de decimales, decia 3 -->
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2189)'" />
					</xsl:message>
				</xsl:if>
			</xsl:if>

			<!-- Precio de venta unitario por item que modifica -->
			<xsl:if
				test="(count(./cac:PricingReference/cac:AlternativeConditionPrice/cbc:PriceTypeCode[text()='01'])>1 or count(./cac:PricingReference/cac:AlternativeConditionPrice/cbc:PriceTypeCode[text()='02'])>1)">
				<xsl:message terminate="yes" >
					<xsl:value-of select="'Error Expr Regular ND  (codigo: 2409)'" />
				</xsl:message>
			</xsl:if>

			<!-- Precio de venta unitario por item que -->
			<xsl:if
				test='./cac:PricingReference/cac:AlternativeConditionPrice/cbc:PriceTypeCode'>
				<xsl:if
					test='not(./cac:PricingReference/cac:AlternativeConditionPrice/cbc:PriceTypeCode=01 or ./cac:PricingReference/cac:AlternativeConditionPrice/cbc:PriceTypeCode=02)'>
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2192)'" />
					</xsl:message>
				</xsl:if>
			</xsl:if>


			<xsl:if
				test='./cac:PricingReference/cac:AlternativeConditionPrice/cbc:PriceAmount'>
				<xsl:choose>
					<xsl:when
						test='./cac:PricingReference/cac:AlternativeConditionPrice/cbc:PriceTypeCode=02 and not(matches(./cac:PricingReference/cac:AlternativeConditionPrice/cbc:PriceAmount,"^[0-9]{1,12}(\.[0-9]{1,10})?$"))'>
						<xsl:message terminate="yes" >
							<xsl:value-of select="'Error Expr Regular ND (codigo: 2408)'" />
						</xsl:message>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if
							test='./cac:PricingReference/cac:AlternativeConditionPrice/cbc:PriceTypeCode=01 and not(matches(./cac:PricingReference/cac:AlternativeConditionPrice/cbc:PriceAmount,"^[0-9]{1,12}(\.[0-9]{1,10})?$"))'>
							<xsl:message terminate="yes" >
								<xsl:value-of select="'Error Expr Regular ND (codigo: 2367)'" />
							</xsl:message>
						</xsl:if>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>

			<!-- Valor unitario por item -->
			<xsl:choose>
				<xsl:when test='not(./cac:Price/cbc:PriceAmount)'>
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2190)'" />
					</xsl:message>
				</xsl:when>
				<xsl:otherwise>
					<xsl:if
						test='not(matches(./cac:Price/cbc:PriceAmount,"^[0-9]{1,12}(\.[0-9]{1,10})?$"))'>
						<xsl:message terminate="yes" >
							<xsl:value-of select="'Error Expr Regular ND (codigo: 2369)'" />
						</xsl:message>
					</xsl:if>
				</xsl:otherwise>
			</xsl:choose>

			<!-- Afectacion al IGV por item - Sistema de ISC por item -->
			<xsl:for-each select="./cac:TaxTotal">
				<xsl:if test='./cbc:TaxAmount'>
					<xsl:if
						test="./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID=1000 and count(./cbc:TaxAmount)>1">
						<xsl:message terminate="yes" >
							<xsl:value-of select="'Error Expr Regular ND (codigo: 2355)'" />
						</xsl:message>
					</xsl:if>
					<xsl:if
						test="./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID=2000 and count(./cbc:TaxAmount)>1">
						<xsl:message terminate="yes" >
							<xsl:value-of select="'Error Expr Regular ND (codigo: 2356)'" />
						</xsl:message>
					</xsl:if>
				</xsl:if>
				<!-- agregado 27/01/2014 inicio -->
				<xsl:if test="./cbc:TaxAmount!=./cac:TaxSubtotal/cbc:TaxAmount">
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2372)'" />
					</xsl:message>
				</xsl:if>
				<!-- agregado 27/01/2014 fin -->

				<xsl:if test='./cac:TaxSubtotal/cbc:TaxAmount'>
					<xsl:if
						test='not(matches(./cac:TaxSubtotal/cbc:TaxAmount,"^[0-9]{1,12}(\.[0-9]{1,2})?$"))'>
						<xsl:message terminate="yes" >
							<xsl:value-of select="'Error Expr Regular ND (codigo: 2368)'" />
						</xsl:message>
					</xsl:if>
				</xsl:if>

				<xsl:if
					test='./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID=1000'>
					<xsl:choose>
						<xsl:when
							test="not(./cac:TaxSubtotal/cac:TaxCategory/cbc:TaxExemptionReasonCode)">
							<xsl:message terminate="yes" >
								<xsl:value-of select="'Error Expr Regular ND (codigo: 2371)'" />
							</xsl:message>
						</xsl:when>
						<xsl:otherwise>
							<xsl:if
								test="not(./cac:TaxSubtotal/cac:TaxCategory/cbc:TaxExemptionReasonCode[text()=10 or text()=11 or text()=12 or text()=13 or text()=14 or 
																		text()=15 or text()=16 or text()=20 or 
																		text()=30 or text()=31 or text()=32 or text()=33 or text()=34 or 
																		text()=35 or text()=36 or text()=40 or text()=21])">
								<xsl:message terminate="yes" >
									<xsl:value-of select="'Error Expr Regular ND (codigo: 2197)'" />
								</xsl:message>
							</xsl:if>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:if>
				<xsl:if
					test='./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID=2000'>
					<xsl:choose>
						<xsl:when
							test="./cbc:TaxAmount>0 and not(string(./cac:TaxSubtotal/cac:TaxCategory/cbc:TierRange))">
							<xsl:message terminate="yes" >
								<xsl:value-of select="'Error Expr Regular ND (codigo: 2373)'" />
							</xsl:message>
						</xsl:when>
						<xsl:otherwise>
							<xsl:if
								test="not(./cac:TaxSubtotal/cac:TaxCategory/cbc:TierRange=01 or ./cac:TaxSubtotal/cac:TaxCategory/cbc:TierRange=02 or ./cac:TaxSubtotal/cac:TaxCategory/cbc:TierRange=03)">
								<xsl:message terminate="yes" >
									<xsl:value-of select="'Error Expr Regular ND (codigo: 2199)'" />
								</xsl:message>
							</xsl:if>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:if>

				<xsl:if test='./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID'>
					<xsl:if
						test='not(matches(./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID,"^[0-9]{4}$"))'>
						<xsl:message terminate="yes" >
							<xsl:value-of select="'Error Expr Regular ND (codigo: 2193)'" />
						</xsl:message>
					</xsl:if>
					<xsl:if
						test="not(./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID=1000 or ./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID=2000)">
						<xsl:message terminate="yes" >
							<xsl:value-of select="'Error Expr Regular ND (codigo: 2194)'" />
						</xsl:message>
					</xsl:if>

					<xsl:choose>
						<xsl:when
							test="not(./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:Name)">
							<xsl:message terminate="yes" >
								<xsl:value-of select="'Error Expr Regular ND (codigo: 2195)'" />
							</xsl:message>
						</xsl:when>
						<xsl:otherwise>
							<xsl:if
								test='not(matches(./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:Name,"^[A-Z]{1,6}?$"))'>
								<xsl:message terminate="yes" >
									<xsl:value-of select="'Error Expr Regular ND (codigo: 2195)'" />
								</xsl:message>
							</xsl:if>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:if>

				<xsl:if test='./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID'>
					<xsl:if
						test='./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID=1000'>
						<xsl:if
							test="not(./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:Name='IGV') or not(./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:TaxTypeCode='VAT')">
							<xsl:message terminate="yes" >
								<xsl:value-of select="'Error Expr Regular ND (codigo: 2377)'" />
							</xsl:message>
						</xsl:if>
					</xsl:if>
					<xsl:if
						test='./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID=2000'>
						<xsl:if
							test="not(./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:Name='ISC') or not(./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:TaxTypeCode='EXC')">
							<xsl:message terminate="yes" >
								<xsl:value-of select="'Error Expr Regular ND (codigo: 2378)'" />
							</xsl:message>
						</xsl:if>
					</xsl:if>
				</xsl:if>

				<xsl:if
					test='./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:TaxTypeCode'>
					<xsl:if
						test='not(matches(./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:TaxTypeCode,"^[A-Z]{3}$|^$"))'>
						<xsl:message terminate="yes" >
							<xsl:value-of select="'Error Expr Regular ND (codigo: 2196)'" />
						</xsl:message>
					</xsl:if>
				</xsl:if>
			</xsl:for-each>

		</xsl:for-each>


		<!-- Sumatoria IGV / ISC / Otros Tributos -->
		<xsl:for-each select="cac:TaxTotal">
			<xsl:choose>
				<xsl:when test="not(./cbc:TaxAmount)">
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2203)'" />
					</xsl:message>
				</xsl:when>
				<xsl:otherwise>
					<xsl:if	test='./cbc:TaxAmount and not(matches(./cbc:TaxAmount,"^[0-9]{1,12}(\.[0-9]{1,2})?$"))'>
						<xsl:message terminate="yes" >
							<xsl:value-of select="'Error Expr Regular ND (codigo: 2202)'" />
						</xsl:message>
					</xsl:if>
				</xsl:otherwise>
			</xsl:choose>

			<xsl:if test='./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID'>
				<xsl:if
					test='./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID=1000'>
					<xsl:if test="count(./cbc:TaxAmount)>1">
						<xsl:message terminate="yes" >
							<xsl:value-of select="'Error Expr Regular ND (codigo: 2352)'" />
						</xsl:message>
					</xsl:if>
				</xsl:if>
				<xsl:if
					test='./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID=2000'>
					<xsl:if test="count(./cbc:TaxAmount)>1">
						<xsl:message terminate="yes" >
							<xsl:value-of select="'Error Expr Regular ND (codigo: 2353)'" />
						</xsl:message>
					</xsl:if>
				</xsl:if>
				<xsl:if
					test='./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID=9999'>
					<xsl:if test="count(./cbc:TaxAmount)>1">
						<xsl:message terminate="yes" >
							<xsl:value-of select="'Error Expr Regular ND (codigo: 2354)'" />
						</xsl:message>
					</xsl:if>
				</xsl:if>
			</xsl:if>

			<xsl:if test="./cac:TaxSubtotal/cbc:TaxAmount">
				<xsl:if test="./cbc:TaxAmount!=./cac:TaxSubtotal/cbc:TaxAmount">
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2061)'" />
					</xsl:message>
				</xsl:if>
			</xsl:if>

			<xsl:choose>
				<xsl:when
					test="not(string(./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID))">
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2184)'" />
					</xsl:message>
				</xsl:when>
				<xsl:otherwise>
					<xsl:if
						test='not(matches(./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID,"^[0-9]{4}$"))'>
						<xsl:message terminate="yes" >
							<xsl:value-of select="'Error Expr Regular ND (codigo: 2182)'" />
						</xsl:message>
					</xsl:if>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:if test="./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID">
				<xsl:if
					test="not(./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID=1000 or ./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID=2000 or ./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID=9999)">
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2183)'" />
					</xsl:message>
				</xsl:if>
			</xsl:if>

			<xsl:choose>
				<xsl:when
					test="not(string(./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:Name))">
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2186)'" />
					</xsl:message>
				</xsl:when>
				<xsl:otherwise>
					<xsl:if	test='not(matches(./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:Name,"^[A-Z]{1,6}$"))'>
						<xsl:message terminate="yes" >
							<xsl:value-of select="'Error Expr Regular ND (codigo: 2185)'" />
						</xsl:message>
					</xsl:if>
				</xsl:otherwise>
			</xsl:choose>

			<xsl:if
				test="./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID=1000 and not(./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:Name='IGV')">
				<xsl:message terminate="yes" >
					<xsl:value-of select="'Error Expr Regular ND (codigo: 2057)'" />
				</xsl:message>
			</xsl:if>
			<xsl:if
				test="./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID=2000 and not(./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:Name='ISC')">
				<xsl:message terminate="yes" >
					<xsl:value-of select="'Error Expr Regular ND (codigo: 2058)'" />
				</xsl:message>
			</xsl:if>

			<xsl:if
				test="./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:TaxTypeCode">
				<xsl:if
					test="./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID=1000 and not(./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:TaxTypeCode='VAT')">
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2057)'" />
					</xsl:message>
				</xsl:if>
				<xsl:if
					test="./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID=2000 and not(./cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:TaxTypeCode='EXC')">
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2058)'" />
					</xsl:message>
				</xsl:if>
			</xsl:if>
		</xsl:for-each>

		<!-- Sumatoria otros Cargos -->
		<xsl:if test="cac:RequestedMonetaryTotal/cbc:ChargeTotalAmount">
			<xsl:if
				test='not(matches(cac:RequestedMonetaryTotal/cbc:ChargeTotalAmount,"^[0-9]{1,12}(\.[0-9]{1,2})?$"))'>
				<xsl:message terminate="yes" >
					<xsl:value-of select="'Error Expr Regular ND (codigo: 2064)'" />
				</xsl:message>
			</xsl:if>
		</xsl:if>

		<!-- Total descuentos - Total valor de venta - operaciones gravadas - operaciones 
			inafectas - operaciones exoneradas -->
		<xsl:for-each
			select="ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/sac:AdditionalInformation/sac:AdditionalMonetaryTotal">
			<xsl:if test='./cbc:PayableAmount'>
				<xsl:if
					test='not(matches(./cbc:PayableAmount,"^[0-9]{1,12}(\.[0-9]{1,2})?$"))'>
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2339)'" />
					</xsl:message>
				</xsl:if>
			</xsl:if>

			<xsl:choose>
				<xsl:when test="not(string(./cbc:ID))">
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2341)'" />
					</xsl:message>
				</xsl:when>
				<xsl:otherwise>
					<xsl:if test='not(matches(./cbc:ID,"^[0-9]{4}$"))'>
						<xsl:message terminate="yes" >
							<xsl:value-of select="'Error Expr Regular ND (codigo: 2340)'" />
						</xsl:message>
					</xsl:if>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:if test="(./cbc:ID=1001 and count(./cbc:ID)>1)">
				<xsl:message terminate="yes" >
					<xsl:value-of select="'Error Expr Regular ND (codigo: 2349)'" />
				</xsl:message>
			</xsl:if>
			<xsl:if test="(./cbc:ID=1002 and count(./cbc:ID)>1)">
				<xsl:message terminate="yes" >
					<xsl:value-of select="'Error Expr Regular ND (codigo: 2350)'" />
				</xsl:message>
			</xsl:if>
			<xsl:if test="(./cbc:ID=1003 and count(./cbc:ID)>1)">
				<xsl:message terminate="yes" >
					<xsl:value-of select="'Error Expr Regular ND (codigo: 2351)'" />
				</xsl:message>
			</xsl:if>
			<xsl:if
				test="(./cbc:ID=1001 and count(./cbc:ID)>1) or (./cbc:ID=1002 and count(./cbc:ID)>1) or (./cbc:ID=1003 and count(./cbc:ID)>1)">
				<xsl:message terminate="yes" >
					<xsl:value-of select="'Error Expr Regular ND (codigo: 2046)'" />
				</xsl:message>
			</xsl:if>
		</xsl:for-each>

		<!-- Importe total -->
		<xsl:if test="cac:RequestedMonetaryTotal/cbc:PayableAmount">
			<xsl:choose>
				<xsl:when
					test="not(string(cac:RequestedMonetaryTotal/cbc:PayableAmount))">
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2201)'" />
					</xsl:message>
				</xsl:when>
				<xsl:otherwise>
					<xsl:if
						test='not(matches(cac:RequestedMonetaryTotal/cbc:PayableAmount,"^[0-9]{1,12}(\.[0-9]{1,2})?$"))'>
						<xsl:message terminate="yes" >
							<xsl:value-of select="'Error Expr Regular ND (codigo: 2062)'" />
						</xsl:message>
					</xsl:if>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>

		<!-- Codigo del tipo de Nota de debito electronica -->
		<xsl:choose>
			<xsl:when test="not(string(cac:DiscrepancyResponse))">
				<xsl:message terminate="yes" >
					<xsl:value-of select="'Error Expr Regular ND (codigo: 2414)'" />
				</xsl:message>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test='count(cac:DiscrepancyResponse)>1'>
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2415)'" />
					</xsl:message>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:choose>
			<xsl:when test="not(string(cac:DiscrepancyResponse/cbc:ResponseCode))">
				<xsl:message terminate="yes" >
					<xsl:value-of select="'Error Expr Regular ND (codigo: 2173)'" />
				</xsl:message>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if
					test='not(matches(cac:DiscrepancyResponse/cbc:ResponseCode,"^[0-9]{2}$"))'>
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2172)'" />
					</xsl:message>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>

		<!-- Motivo o Sustento -->
		<xsl:choose>
			<xsl:when test="not(string(cac:DiscrepancyResponse/cbc:Description))">
			  <xsl:message terminate="yes" >
					<xsl:value-of select="'Error Expr Regular ND (codigo: 2136)'" />
				</xsl:message>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if
					test='not(matches(cac:DiscrepancyResponse/cbc:Description,"^[A-Z0-9]{1,250}"))'>
									<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2135)'" />
					</xsl:message>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>


		<!-- Nota de debito para penalidades no importa si viene el documento que 
			modifica -->

		<xsl:if test="cac:DiscrepancyResponse/cbc:ResponseCode != '03'">

			<!-- tipo de nota F facturas y tickets B boletas -->

			<xsl:variable name="tipoDocumentoModifica" select="string(substring(cbc:ID, 1, 1))" />

			<xsl:for-each select="cac:BillingReference/cac:InvoiceDocumentReference">

				<xsl:if
					test="$tipoDocumentoModifica ='F' and not(./cbc:DocumentTypeCode[text() = '01' or text() = '12' or text() = '56'])">
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2204)'" />
					</xsl:message>
				</xsl:if>

				<xsl:if
					test="$tipoDocumentoModifica ='B' and not(./cbc:DocumentTypeCode[text() = '03'])">
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2400)'" />
					</xsl:message>
				</xsl:if>

				<xsl:if
					test="./cbc:DocumentTypeCode[text() = '01'] and not(matches(./cbc:ID,'^[F][A-Z0-9]{3}-[0-9]{1,8}?$|^(E001)-[0-9]{1,8}?$|^[B][A-Z0-9]{3}-[0-9]{1,8}?$|^[0-9]{1,4}-[0-9]{1,8}?$') ) ">
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2205)'" />
					</xsl:message>
				</xsl:if>


				<xsl:if
					test="./cbc:DocumentTypeCode[text() = '12'] and not(matches(./cbc:ID,'^[a-zA-Z0-9-]{1,20}-[0-9]{1,10}?$') ) ">
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2205)'" />
					</xsl:message>
				</xsl:if>


				<xsl:if
					test="./cbc:DocumentTypeCode[text() = '56'] and not(matches(./cbc:ID,'^[\s]*$') ) ">
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2205)'" />
					</xsl:message>
				</xsl:if>


				<xsl:if
					test="./cbc:DocumentTypeCode[text() = '03'] and not(matches(./cbc:ID,'^[B][A-Z0-9]{3}-[0-9]{1,8}?$|^[0-9]{1,4}-[0-9]{1,8}?$') ) ">
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2205)'" />
					</xsl:message>
				</xsl:if>

				<xsl:if test='count(./cbc:ID)=0'>
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2206)'" />
					</xsl:message>
				</xsl:if>
			</xsl:for-each>



			<xsl:choose>
				<xsl:when test="not(string(cac:DiscrepancyResponse/cbc:ReferenceID))">
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2171)'" />
					</xsl:message>
				</xsl:when>
				<xsl:otherwise>
					<xsl:if
						test='not(matches(cac:DiscrepancyResponse/cbc:ReferenceID,"^[F][A-Z0-9]{3}-[0-9]{1,8}?$|^[B][A-Z0-9]{3}-[0-9]{1,8}?$|^[0-9]{1,4}-[0-9]{1,8}?$") )'>
						<xsl:message terminate="yes" >
							<xsl:value-of select="'Error Expr Regular ND (codigo: 2170)'" />
						</xsl:message>
					</xsl:if>
				</xsl:otherwise>
			</xsl:choose>

		</xsl:if>



		<!-- Documento de referencia -->
		<xsl:if test="cac:DespatchDocumentReference/cbc:DocumentTypeCode">
			<xsl:choose>
				<xsl:when
					test='not(matches(cac:DespatchDocumentReference/cbc:DocumentTypeCode,"^[0-9]{2}$"))'>
            <xsl:message terminate="no" >
							<xsl:value-of select="'Error Expr Regular ND (codigo: 4004)'" />
						</xsl:message>
				</xsl:when>
				<xsl:otherwise>
					<xsl:if
						test="not((cac:DespatchDocumentReference/cbc:DocumentTypeCode=09) or (cac:DespatchDocumentReference/cbc:DocumentTypeCode=31))">
						<xsl:message terminate="no" >
							<xsl:value-of select="'Error Expr Regular ND (codigo: 4005)'" />
						</xsl:message>
					</xsl:if>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>

		<xsl:if test="cac:DespatchDocumentReference/cbc:ID">
			<xsl:choose>
				<xsl:when test='not(cac:DespatchDocumentReference/cbc:ID)'>
					<xsl:message terminate="no" >
							<xsl:value-of select="'Error Expr Regular ND (codigo: 4007)'" />
						</xsl:message>
				</xsl:when>
				<xsl:otherwise>
					<xsl:if
						test='not(matches(cac:DespatchDocumentReference/cbc:ID,"^(.){1,4}-[0-9]{1,}$"))'>
						<xsl:message terminate="no" >
							<xsl:value-of select="'Error Expr Regular ND (codigo: 4006)'" />
						</xsl:message>
					</xsl:if>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>

		<xsl:if test="cac:AdditionalDocumentReference/cbc:DocumentTypeCode">
			<xsl:choose>
				<xsl:when
					test='not(matches(cac:AdditionalDocumentReference/cbc:DocumentTypeCode,"^[0-9]{2}$"))'>
					<xsl:message terminate="no" >
							<xsl:value-of select="'Error Expr Regular ND (codigo: 4008)'" />
						</xsl:message>
				</xsl:when>
				<xsl:otherwise>
					<xsl:if
						test="not((cac:AdditionalDocumentReference/cbc:DocumentTypeCode=04) or (cac:AdditionalDocumentReference/cbc:DocumentTypeCode=05) or (cac:AdditionalDocumentReference/cbc:DocumentTypeCode=99) or (cac:AdditionalDocumentReference/cbc:DocumentTypeCode=01))">
						<xsl:message terminate="no" >
							<xsl:value-of select="'Error Expr Regular ND (codigo: 4009)'" />
						</xsl:message>
					</xsl:if>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>

		<xsl:if test="cac:AdditionalDocumentReference/cbc:ID">
			<xsl:choose>
				<xsl:when test='not(cac:AdditionalDocumentReference/cbc:ID)'>
					<xsl:message terminate="no" >
							<xsl:value-of select="'Error Expr Regular ND (codigo: 4011)'" />
						</xsl:message>
				</xsl:when>
				<xsl:otherwise>
					<xsl:if
						test='	not(matches(cac:AdditionalDocumentReference/cbc:ID,"^^[0-9]{1,6}?$"))'>
						<xsl:message terminate="no" >
							<xsl:value-of select="'Error Expr Regular ND (codigo: 4010)'" />
						</xsl:message>
					</xsl:if>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	

		<!-- NUEVAS VALIDACIONES 27/01/2014 inicio -->
		<!-- Tipo de moneda en la cual se emite la NOTA DE DEBITO electronica -->
		<xsl:choose>
			<xsl:when test="not(string(cbc:DocumentCurrencyCode))">
					<xsl:message terminate="yes" >
					<xsl:value-of select="'Error Expr Regular ND (codigo: 2070)'" />
				</xsl:message>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if
					test='not(matches(cbc:DocumentCurrencyCode,"^[A-Z0-9]{3}$"))'>
					<xsl:message terminate="yes" >
						<xsl:value-of select="'Error Expr Regular ND (codigo: 2069)'" />
					</xsl:message>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:if
			test="(cbc:DocumentCurrencyCode!=cac:TaxTotal/cbc:TaxAmount/@currencyID) or (cbc:DocumentCurrencyCode!=cac:TaxTotal/cac:TaxSubtotal/cbc:TaxAmount/@currencyID) or (cbc:DocumentCurrencyCode!=cac:LegalMonetaryTotal/cbc:ChargeTotalAmount/@currencyID) or (cbc:DocumentCurrencyCode!=cac:DebitNoteLine/cac:PricingReference/cac:AlternativeConditionPrice/cbc:PriceAmount/@currencyID) or (cbc:DocumentCurrencyCode!=cac:DebitNoteLine/cac:Price/cbc:PriceAmount/@currencyID) or (cbc:DocumentCurrencyCode!=cac:DebitNoteLine/cbc:LineExtensionAmount/@currencyID) or (cbc:DocumentCurrencyCode!=cac:DebitNoteLine/cac:TaxTotal/cbc:TaxAmount/@currencyID) or (cbc:DocumentCurrencyCode!=cac:DebitNoteLine/cac:TaxTotal/cac:TaxSubtotal/cbc:TaxAmount/@currencyID)">
				<xsl:message terminate="yes" >
				<xsl:value-of select="'Error Expr Regular ND (codigo: 2071)'" />
			</xsl:message>
		</xsl:if>
		<xsl:if
			test="(cbc:DocumentCurrencyCode!=ext:UBLExtensions/ext:UBLExtension/ext:ExtensionContent/sac:AdditionalInformation/sac:AdditionalMonetaryTotal/cbc:PayableAmount/@currencyID)">
				<xsl:message terminate="yes" >
				<xsl:value-of select="'Error Expr Regular ND (codigo: 2071)'" />
			</xsl:message>
		</xsl:if>


		<!-- NUEVAS VALIDACIONES 27/01/2014 fin -->
		<!-- Documentos Relacionados Duplicados -->

		<xsl:for-each select="cac:BillingReference">
			<xsl:if
				test="count(key('by-document-billing-reference', concat(cac:InvoiceDocumentReference/cbc:DocumentTypeCode,' ', cac:InvoiceDocumentReference/cbc:ID))) > 1">
					<xsl:message terminate="yes" >
					<xsl:value-of select="'Error Expr Regular ND  (codigo: 2365)'" />
				</xsl:message>
			</xsl:if>
		</xsl:for-each>

		<xsl:for-each select="cac:DespatchDocumentReference">
			<xsl:if
				test="count(key('by-document-despatch-reference', concat(cbc:DocumentTypeCode,' ', cbc:ID))) > 1">
				<xsl:message terminate="yes" >
					<xsl:value-of select="'Error Expr Regular ND  (codigo: 2364)'" />
				</xsl:message>
			</xsl:if>
		</xsl:for-each>

		<xsl:for-each select="cac:AdditionalDocumentReference">
			<xsl:if
				test="count(key('by-document-additional-reference', concat(cbc:DocumentTypeCode,' ', cbc:ID))) > 1">
					<xsl:message terminate="yes" >
					<xsl:value-of select="'Error Expr Regular ND  (codigo: 2426)'" />
				</xsl:message>
			</xsl:if>
		</xsl:for-each>
	
		<xsl:copy-of select="." />
	</xsl:template>
</xsl:stylesheet>